@@ -20,23 +20,23 @@ impl Color {
 	}
 
 	/// Accurate but slow alpha-blending function
-	pub fn blend(src: Color, dst: Color, opacity: f32) -> Color {
+	pub fn blend_slow(src: Color, dst: Color, opacity: f64) -> Color {
 		if src.a <= 0 { return Color::clear(); }
 
-		let src_rf32 = src.r as f32 / 255.0;
-		let src_gf32 = src.g as f32 / 255.0;
-		let src_bf32 = src.b as f32 / 255.0;
-		let src_af32 = (src.a as f32 / 255.0) * opacity;
+		let src_rf64 = src.r as f64 / 255.0;
+		let src_gf64 = src.g as f64 / 255.0;
+		let src_bf64 = src.b as f64 / 255.0;
+		let src_af64 = (src.a as f64 / 255.0) * opacity;
 
-		let dst_rf32 = dst.r as f32 / 255.0;
-		let dst_gf32 = dst.g as f32 / 255.0;
-		let dst_bf32 = dst.b as f32 / 255.0;
-		let dst_af32 = dst.a as f32 / 255.0;
+		let dst_rf64 = dst.r as f64 / 255.0;
+		let dst_gf64 = dst.g as f64 / 255.0;
+		let dst_bf64 = dst.b as f64 / 255.0;
+		let dst_af64 = dst.a as f64 / 255.0;
 
-		let fa = src_af32 + dst_af32 * (1.0 - src_af32);
-		let fr = (src_rf32 * src_af32 + dst_rf32 * (1.0 - src_af32)) / fa;
-		let fg = (src_gf32 * src_af32 + dst_gf32 * (1.0 - src_af32)) / fa;
-		let fb = (src_bf32 * src_af32 + dst_bf32 * (1.0 - src_af32)) / fa;
+		let fa = src_af64 + dst_af64 * (1.0 - src_af64);
+		let fr = (src_rf64 * src_af64 + dst_rf64 * (1.0 - src_af64)) / fa;
+		let fg = (src_gf64 * src_af64 + dst_gf64 * (1.0 - src_af64)) / fa;
+		let fb = (src_bf64 * src_af64 + dst_bf64 * (1.0 - src_af64)) / fa;
 
 		let r = (fr * 255.0).round() as u8;
 		let g = (fg * 255.0).round() as u8;
@@ -46,7 +46,7 @@ impl Color {
 		Color { r, g, b, a}
 	}
 
-	/// Faster but less accurate alpha-blending function. Recommended for performance
+	/// Faster but less accurate alpha-blending function. Used in rasterizer since it's accurate enough and removes branching in hot code
 	/// <https://www.codeguru.com/cpp/cpp/algorithms/general/article.php/c15989/Tip-An-Optimized-Formula-for-Alpha-Blending-Pixels.htm>
 	pub fn blend_fast(src: Color, dst: Color, opacity: u8) -> Color {
 		let alpha: u32 = (src.a - (255 - opacity)) as u32;
@@ -78,13 +78,13 @@ impl Color {
 	}
 
 	/// Hue, Saturation, and Value color definition. Should not be used per pixel due to casting and division use.
-	pub fn hsv(hue: f32, saturation: f32, value: f32) -> Color {
+	pub fn hsv(hue: f64, saturation: f64, value: f64) -> Color {
 		let hi: i32 = ((hue / 60.0).floor() as i32) % 6;
-		let f: f32 = (hue / 60.0) - (hue / 60.0).floor();
+		let f: f64 = (hue / 60.0) - (hue / 60.0).floor();
 
-		let p: f32 = value * (1.0 - saturation);
-		let q: f32 = value * (1.0 - (f * saturation));
-		let t: f32 = value * (1.0 - ((1.0 - f) * saturation));
+		let p: f64 = value * (1.0 - saturation);
+		let q: f64 = value * (1.0 - (f * saturation));
+		let t: f64 = value * (1.0 - ((1.0 - f) * saturation));
 
 		match hi
 		{
@@ -98,7 +98,7 @@ impl Color {
 		}
 	}
 
-	pub fn lerp_rgb(c1: Color, c2: Color, t: f32) -> Color {
+	pub fn lerp_rgb(c1: Color, c2: Color, t: f64) -> Color {
 		let tb = (clampf(t, 0.0, 1.0) / 255.0) as u8;
 		let mut cf: Color = Color::clear();
 
@@ -141,14 +141,6 @@ impl Color {
 	pub fn cyan() -> Color {
 		Color { r: 0, g: 255, b: 255, a: 255 }
 	}
-
-	pub fn magenta() -> Color {
-		Color { r: 255, g: 0, b: 255, a: 255 }
-	}
-
-	pub fn orange() -> Color {
-		Color { r: 255, g: 128, b: 0, a: 255 }
-	}
 }
 
 impl std::ops::Add for Color {
