@@ -19,7 +19,6 @@ pub mod font;
 pub mod math;
 pub mod drawables;
 pub mod color;
-pub mod random;
 
 // Math 2D
 pub mod vector2;
@@ -30,4 +29,5 @@ pub mod matrix4;
 pub mod vector3;
 
 // 3D Utilities
-pub mod three;
\ No newline at end of file
+// Not public because unfinished
+mod three;
\ No newline at end of file
